@@ -4,6 +4,7 @@ import htmlgenerator as hg
 from django.conf import settings
 from django.db import models
 from django.db.models import ManyToOneRel
+from django.db.models.fields.related_descriptors import ReverseManyToOneDescriptor
 from django.template.defaultfilters import linebreaksbr
 from django.utils.formats import localize as djangolocalize
 from django.utils.timezone import localtime as djangolocaltime
@@ -78,6 +79,9 @@ class ObjectFieldLabel(hg.ContextValue):
             label,
         )  # test for annotated ("dynamic") fields
 
+        if isinstance(label, ReverseManyToOneDescriptor):
+            label = label.rel.field.remote_field
+
         if hasattr(label, "verbose_name"):
             return label.verbose_name
         if isinstance(label, property):
@@ -134,6 +138,14 @@ class ObjectFieldValue(hg.Lazy):
 
         if self.formatter:
             value = self.formatter(value)
+
+        if value in (True, False, None):
+            value = {
+                True: settings.HTML_TRUE,
+                False: settings.HTML_FALSE,
+                None: settings.HTML_NONE,
+            }[value]
+
         value = djangolocalize(value, use_l10n=settings.USE_L10N)
         if isinstance(value, models.Manager):
             value = ", ".join([str(x) for x in value.all()])
